#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Setuptools build script for DCCL Bindings."""
__author__ = "Chris Murphy, Toby Schneider"
__copyright__ = "Copyright 2018-2019, The DCCL Project"
__license__ = "LGPL"

from setuptools import setup, find_packages
from setuptools.extension import Extension
from distutils.command.clean import clean as _clean
from distutils.command.build_py import build_py as _build_py
import subprocess
import os, sys
import time

def get_version():
    return open('version.txt', 'r').readline().strip()

class clean(_clean):
  def run(self):
    # Delete generated files in the code tree.
    for (dirpath, dirnames, filenames) in os.walk("."):
      for filename in filenames:
        filepath = os.path.join(dirpath, filename)
        if filepath.endswith("_pb2.py") or filepath.endswith(".pyc") or \
          filepath.endswith(".so") or filepath.endswith(".o"):
          os.remove(filepath)
    # _clean is an old-style class, so super() doesn't work.
    _clean.run(self)

class build_py(_build_py):
  def run(self):
    # Generate option_extension.proto file.
    protoc_command = ['protoc', '-Iinclude/', '-I/usr/include', '--python_out=.', 'include/dccl/option_extensions.proto']
    if subprocess.call(protoc_command) != 0:
      sys.exit(-1)

    # _build_py is an old-style class, so super() doesn't work.
    _build_py.run(self)

setup(
    name="dccl",
    version=get_version(),
    description="Python Bindings for DCCL.",
    author="Chris Murphy",
    author_email="cmurphy@aphysci.com",

    packages=find_packages(),

    ext_modules = [
        Extension(
            "dccl._dccl",
            ["dccl/_dccl.cc"],
            libraries=['dccl', 'protobuf'],
            extra_compile_args = ["-Wno-write-strings", "-std=c++11"], # Hide a bunch of c++ warnings.
        )
    ],

    # Override clean + build to support protobuf.
    cmdclass={
        'clean': clean,
        'build_py': build_py,
    }

)

